==> eslint-config-mctep-0.0.2.tgz: package/index.js <==
/* eslint no-magic-numbers:'off' */

module.exports = {
	env: {
		es6: true,
		node: true,
	},

	plugins: [
		'import',
	],

	rules: {
		'accessor-pairs': 'error',
		'array-bracket-spacing': ['error', 'never'],
		'array-callback-return': 'error',
		'arrow-body-style': ['error', 'always'],
		'arrow-parens': 'error',
		'arrow-spacing': 'error',
		'block-scoped-var': 'error',
		'block-spacing': 'error',
		'brace-style': ['error', '1tbs', { allowSingleLine: true }],
		'callback-return': 'error',
		camelcase: 'error',
		'class-methods-use-this': 'error',
		'comma-dangle': ['error', 'always-multiline'],
		'comma-spacing': 'error',
		'comma-style': 'error',
		complexity: ['error', 4],
		'computed-property-spacing': 'error',
		'consistent-return': 'error',
		'consistent-this': 'error',
		'constructor-super': 'error',
		curly: 'error',
		'default-case': 'error',
		'dot-location': ['error', 'property'],
		'dot-notation': 'error',
		'eol-last': 'error',
		eqeqeq: 'error',
		'func-call-spacing': 'error',
		'func-name-matching': 'error',
		'func-names': 'error',
		'func-style': ['error', 'declaration'],
		'generator-star-spacing': ['error', { after: true, before: true }],
		'global-require': 'error',
		'guard-for-in': 'error',
		'handle-callback-err': ['error', '^err(or)?$'],
		'id-blacklist': 'error',
		'id-length': ['error', { min: 3 }],
		'id-match': 'error',

		'import/default': 'error',
		'import/export': 'error',
		'import/extensions': 'error',
		'import/first': 'error',
		'import/imports-first': 'error',
		'import/max-dependencies': ['error', { max: 10 }],
		'import/named': 'error',
		'import/namespace': 'error',
		'import/newline-after-import': 'error',
		'import/no-absolute-path': 'error',
		'import/no-amd': 'error',
		'import/no-commonjs': 'off',
		'import/no-deprecated': 'error',
		'import/no-duplicates': 'error',
		'import/no-dynamic-require': 'error',
		'import/no-extraneous-dependencies': ['error', {
			devDependencies: false,
			optionalDependencies: false,
			peerDependencies: false,
		}],
		'import/no-internal-modules': 'off',
		'import/no-mutable-exports': 'error',
		'import/no-named-as-default': 'error',
		'import/no-named-as-default-member': 'error',
		'import/no-named-default': 'error',
		'import/no-namespace': 'error',
		'import/no-nodejs-modules': 'off',
		'import/no-restricted-paths': 'error',
		'import/no-unassigned-import': 'error',
		'import/no-unresolved': ['error', { commonjs: true }],
		'import/no-webpack-loader-syntax': 'error',
		'import/order': 'error',
		'import/prefer-default-export': 'error',
		'import/unambiguous': 'error',

		indent: ['error', 'tab', { SwitchCase: 1 }],
		'init-declarations': 'error',
		'jsx-quotes': 'error',
		'key-spacing': 'error',
		'keyword-spacing': 'error',
		'line-comment-position': 'error',
		'linebreak-style': 'error',
		'lines-around-comment': ['error', {
			allowArrayStart: true,
			allowBlockStart: true,
			allowObjectStart: true,
			beforeBlockComment: true,
			beforeLineComment: true,
		}],
		'lines-around-directive': 'error',
		'max-depth': ['error', 3],
		'max-len': ['error', { code: 80, ignoreUrls: true, tabWidth: 2 }],
		'max-lines': ['error', { skipComments: true }],
		'max-nested-callbacks': ['error', 2],
		'max-params': ['error', 4],
		'max-statements': ['error', 20],
		'max-statements-per-line': ['error', { max: 1 }],
		'multiline-ternary': 'error',
		'new-cap': 'error',
		'new-parens': 'error',
		'newline-after-var': 'error',
		'newline-before-return': 'error',
		'newline-per-chained-call': ['error', { ignoreChainWithDepth: 3 }],
		'no-alert': 'error',
		'no-array-constructor': 'error',
		'no-bitwise': 'error',
		'no-caller': 'error',
		'no-case-declarations': 'error',
		'no-catch-shadow': 'error',
		'no-class-assign': 'error',
		'no-cond-assign': 'error',
		'no-confusing-arrow': 'error',
		'no-console': 'error',
		'no-const-assign': 'error',
		'no-constant-condition': 'error',
		'no-continue': 'error',
		'no-control-regex': 'error',
		'no-debugger': 'error',
		'no-delete-var': 'error',
		'no-div-regex': 'error',
		'no-dupe-args': 'error',
		'no-dupe-class-members': 'error',
		'no-dupe-keys': 'error',
		'no-duplicate-case': 'error',
		'no-duplicate-imports': 'error',
		'no-else-return': 'error',
		'no-empty': 'error',
		'no-empty-character-class': 'error',
		'no-empty-function': 'error',
		'no-empty-pattern': 'error',
		'no-eq-null': 'error',
		'no-eval': 'error',
		'no-ex-assign': 'error',
		'no-extend-native': 'error',
		'no-extra-bind': 'error',
		'no-extra-boolean-cast': 'error',
		'no-extra-label': 'error',
		'no-extra-parens': 'error',
		'no-extra-semi': 'error',
		'no-fallthrough': 'error',
		'no-floating-decimal': 'error',
		'no-func-assign': 'error',
		'no-global-assign': 'error',
		'no-implicit-coercion': 'error',
		'no-implicit-globals': 'error',
		'no-implied-eval': 'error',
		'no-inline-comments': 'error',
		'no-inner-declarations': 'error',
		'no-invalid-regexp': 'error',
		'no-invalid-this': 'error',
		'no-irregular-whitespace': 'error',
		'no-iterator': 'error',
		'no-label-var': 'error',
		'no-labels': 'error',
		'no-lone-blocks': 'error',
		'no-lonely-if': 'error',
		'no-loop-func': 'error',
		'no-magic-numbers': 'error',
		'no-mixed-operators': 'error',
		'no-mixed-requires': 'error',
		'no-mixed-spaces-and-tabs': 'error',
		'no-multi-spaces': 'error',
		'no-multi-str': 'error',
		'no-multiple-empty-lines': 'error',
		'no-native-reassign': 'error',
		'no-negated-condition': 'error',
		'no-negated-in-lhs': 'error',
		'no-nested-ternary': 'error',
		'no-new': 'error',
		'no-new-func': 'error',
		'no-new-object': 'error',
		'no-new-require': 'error',
		'no-new-symbol': 'error',
		'no-new-wrappers': 'error',
		'no-obj-calls': 'error',
		'no-octal': 'error',
		'no-octal-escape': 'error',
		'no-param-reassign': 'error',
		'no-path-concat': 'error',
		'no-plusplus': 'error',
		'no-process-env': 'error',
		'no-process-exit': 'error',
		'no-proto': 'error',
		'no-prototype-builtins': 'error',
		'no-redeclare': 'error',
		'no-regex-spaces': 'error',
		'no-restricted-globals': 'error',
		'no-restricted-imports': 'error',
		'no-restricted-modules': 'error',
		'no-restricted-properties': 'error',
		'no-restricted-syntax': 'error',
		'no-return-assign': 'error',
		'no-script-url': 'error',
		'no-self-assign': 'error',
		'no-self-compare': 'error',
		'no-sequences': 'error',
		'no-shadow': 'error',
		'no-shadow-restricted-names': 'error',
		'no-spaced-func': 'error',
		'no-sparse-arrays': 'error',
		'no-sync': 'error',
		'no-tabs': 'off',
		'no-template-curly-in-string': 'error',
		'no-ternary': 'off',
		'no-this-before-super': 'error',
		'no-throw-literal': 'error',
		'no-trailing-spaces': 'error',
		'no-undef': 'error',
		'no-undef-init': 'error',
		'no-undefined': 'error',
		'no-underscore-dangle': 'error',
		'no-unexpected-multiline': 'error',
		'no-unmodified-loop-condition': 'error',
		'no-unneeded-ternary': 'error',
		'no-unreachable': 'error',
		'no-unsafe-finally': 'error',
		'no-unsafe-negation': 'error',
		'no-unused-expressions': 'error',
		'no-unused-labels': 'error',
		'no-unused-vars': 'error',
		'no-use-before-define': ['error', 'nofunc'],
		'no-useless-call': 'error',
		'no-useless-computed-key': 'error',
		'no-useless-concat': 'error',
		'no-useless-constructor': 'error',
		'no-useless-escape': 'error',
		'no-useless-rename': 'error',
		'no-useless-return': 'error',
		'no-var': 'error',
		'no-void': 'error',
		'no-warning-comments': 'error',
		'no-whitespace-before-property': 'error',
		'no-with': 'error',
		'object-curly-newline': 'off',
		'object-curly-spacing': ['error', 'always'],
		'object-property-newline': ['error', {
			allowMultiplePropertiesPerLine: true,
		}],
		'object-shorthand': 'error',
		'one-var': ['error', 'never'],
		'one-var-declaration-per-line': ['error', 'always'],
		'operator-assignment': 'error',
		'operator-linebreak': ['error', 'after', {
			overrides: {
				':': 'before',
				'?': 'before',
			},
		}],
		'padded-blocks': ['error', 'never'],
		'prefer-arrow-callback': ['error', { allowNamedFunctions: true }],
		'prefer-const': 'error',
		'prefer-numeric-literals': 'error',
		'prefer-reflect': 'error',
		'prefer-rest-params': 'error',
		'prefer-spread': 'error',
		'prefer-template': 'error',
		'quote-props': ['error', 'as-needed'],
		quotes: ['error', 'single'],
		radix: 'error',
		'require-jsdoc': 'off',
		'require-yield': 'error',
		'rest-spread-spacing': 'error',
		semi: ['error', 'always'],
		'semi-spacing': 'error',
		'sort-imports': 'error',
		'sort-keys': 'error',
		'sort-vars': 'error',
		'space-before-blocks': 'error',
		'space-before-function-paren': ['error', 'never'],
		'space-in-parens': ['error', 'never'],
		'space-infix-ops': 'error',
		'space-unary-ops': 'error',
		'spaced-comment': 'error',
		strict: ['error', 'never'],
		'symbol-description': 'error',
		'template-curly-spacing': 'error',
		'unicode-bom': 'error',
		'use-isnan': 'error',
		'valid-jsdoc': 'error',
		'valid-typeof': ['error', { requireStringLiterals: true }],
		'vars-on-top': 'error',
		'wrap-iife': 'error',
		'wrap-regex': 'error',
		'yield-star-spacing': ['error', 'both'],
		yoda: 'error',
	},
};

==> eslint-config-mctep-0.0.4.tgz: package/index.js <==
/* eslint no-magic-numbers:'off', max-lines:'off' */

module.exports = {
	env: {
		es6: true,
		node: true,
	},

	plugins: ['import'],

	rules: {
		'accessor-pairs': 'error',
		'array-bracket-newline': 'off',
		'array-bracket-spacing': ['error', 'never'],
		'array-callback-return': 'error',
		'array-element-newline': 'off',
		'arrow-body-style': ['error', 'always'],
		'arrow-parens': 'error',
		'arrow-spacing': 'error',
		'block-scoped-var': 'error',
		'block-spacing': 'error',
		'brace-style': ['error', '1tbs', { allowSingleLine: true }],
		'callback-return': 'error',
		camelcase: 'error',
		'capitalized-comments': ['error', 'never'],
		'class-methods-use-this': 'error',
		'comma-dangle': ['error', 'always-multiline'],
		'comma-spacing': 'error',
		'comma-style': 'error',
		complexity: ['error', 4],
		'computed-property-spacing': 'error',
		'consistent-return': 'error',
		'consistent-this': 'error',
		'constructor-super': 'error',
		curly: 'error',
		'default-case': 'error',
		'dot-location': ['error', 'property'],
		'dot-notation': 'error',
		'eol-last': 'error',
		eqeqeq: 'error',
		'for-direction': 'error',
		'func-call-spacing': 'error',
		'func-name-matching': 'error',
		'func-names': 'error',
		'func-style': ['error', 'declaration'],
		'generator-star-spacing': ['error', { after: true, before: true }],
		'global-require': 'error',
		'guard-for-in': 'error',
		'handle-callback-err': ['error', '^err(or)?$'],
		'id-blacklist': 'error',
		'id-length': ['error', { min: 3 }],
		'id-match': 'error',

		'import/default': 'error',
		'import/export': 'error',
		'import/extensions': 'error',
		'import/first': 'error',
		'import/imports-first': 'error',
		'import/max-dependencies': ['error', { max: 10 }],
		'import/named': 'error',
		'import/namespace': 'error',
		'import/newline-after-import': 'error',
		'import/no-absolute-path': 'error',
		'import/no-amd': 'error',
		'import/no-anonymous-default-export': 'error',
		'import/no-commonjs': 'off',
		'import/no-deprecated': 'error',
		'import/no-duplicates': 'error',
		'import/no-dynamic-require': 'error',
		'import/no-extraneous-dependencies': ['error', {
			devDependencies: false,
			optionalDependencies: false,
			peerDependencies: false,
		}],
		'import/no-internal-modules': 'off',
		'import/no-mutable-exports': 'error',
		'import/no-named-as-default': 'error',
		'import/no-named-as-default-member': 'error',
		'import/no-named-default': 'error',
		'import/no-namespace': 'error',
		'import/no-nodejs-modules': 'off',
		'import/no-restricted-paths': 'error',
		'import/no-unassigned-import': 'error',
		'import/no-unresolved': ['error', { commonjs: true }],
		'import/no-webpack-loader-syntax': 'error',
		'import/order': 'error',
		'import/prefer-default-export': 'error',
		'import/unambiguous': 'error',

		indent: ['error', 'tab', { SwitchCase: 1 }],
		'init-declarations': 'error',
		'jsx-quotes': 'error',
		'key-spacing': 'error',
		'keyword-spacing': 'error',
		'line-comment-position': 'error',
		'linebreak-style': 'error',
		'lines-around-comment': ['error', {
			allowArrayStart: true,
			allowBlockStart: true,
			allowObjectStart: true,
			beforeBlockComment: true,
			beforeLineComment: true,
		}],
		'max-depth': ['error', 3],
		'max-len': ['error', { code: 80, ignoreUrls: true, tabWidth: 2 }],
		'max-lines': ['error', { skipComments: true }],
		'max-nested-callbacks': ['error', 2],
		'max-params': ['error', 4],
		'max-statements': ['error', 20],
		'max-statements-per-line': ['error', { max: 1 }],
		'multiline-ternary': 'error',
		'new-cap': 'error',
		'new-parens': 'error',
		'newline-per-chained-call': ['error', { ignoreChainWithDepth: 3 }],
		'no-alert': 'error',
		'no-array-constructor': 'error',
		'no-await-in-loop': 'error',
		'no-bitwise': 'error',
		'no-buffer-constructor': 'error',
		'no-caller': 'error',
		'no-case-declarations': 'error',
		'no-catch-shadow': 'error',
		'no-class-assign': 'error',
		'no-compare-neg-zero': 'error',
		'no-cond-assign': 'error',
		'no-confusing-arrow': 'error',
		'no-console': 'error',
		'no-const-assign': 'error',
		'no-constant-condition': 'error',
		'no-continue': 'error',
		'no-control-regex': 'error',
		'no-debugger': 'error',
		'no-delete-var': 'error',
		'no-div-regex': 'error',
		'no-dupe-args': 'error',
		'no-dupe-class-members': 'error',
		'no-dupe-keys': 'error',
		'no-duplicate-case': 'error',
		'no-duplicate-imports': 'error',
		'no-else-return': 'error',
		'no-empty': 'error',
		'no-empty-character-class': 'error',
		'no-empty-function': 'error',
		'no-empty-pattern': 'error',
		'no-eq-null': 'error',
		'no-eval': 'error',
		'no-ex-assign': 'error',
		'no-extend-native': 'error',
		'no-extra-bind': 'error',
		'no-extra-boolean-cast': 'error',
		'no-extra-label': 'error',
		'no-extra-parens': 'error',
		'no-extra-semi': 'error',
		'no-fallthrough': 'error',
		'no-floating-decimal': 'error',
		'no-func-assign': 'error',
		'no-global-assign': 'error',
		'no-implicit-coercion': 'error',
		'no-implicit-globals': 'error',
		'no-implied-eval': 'error',
		'no-inline-comments': 'error',
		'no-inner-declarations': 'error',
		'no-invalid-regexp': 'error',
		'no-invalid-this': 'error',
		'no-irregular-whitespace': 'error',
		'no-iterator': 'error',
		'no-label-var': 'error',
		'no-labels': 'error',
		'no-lone-blocks': 'error',
		'no-lonely-if': 'error',
		'no-loop-func': 'error',
		'no-magic-numbers': 'error',
		'no-mixed-operators': 'error',
		'no-mixed-requires': 'error',
		'no-mixed-spaces-and-tabs': 'error',
		'no-multi-assign': 'error',
		'no-multi-spaces': 'error',
		'no-multi-str': 'error',
		'no-multiple-empty-lines': 'error',
		'no-negated-condition': 'error',
		'no-nested-ternary': 'error',
		'no-new': 'error',
		'no-new-func': 'error',
		'no-new-object': 'error',
		'no-new-require': 'error',
		'no-new-symbol': 'error',
		'no-new-wrappers': 'error',
		'no-obj-calls': 'error',
		'no-octal': 'error',
		'no-octal-escape': 'error',
		'no-param-reassign': 'error',
		'no-path-concat': 'error',
		'no-plusplus': 'error',
		'no-process-env': 'error',
		'no-process-exit': 'error',
		'no-proto': 'error',
		'no-prototype-builtins': 'error',
		'no-redeclare': 'error',
		'no-regex-spaces': 'error',
		'no-restricted-globals': 'error',
		'no-restricted-imports': 'error',
		'no-restricted-modules': 'error',
		'no-restricted-properties': 'error',
		'no-restricted-syntax': 'error',
		'no-return-assign': 'error',
		'no-return-await': 'error',
		'no-script-url': 'error',
		'no-self-assign': 'error',
		'no-self-compare': 'error',
		'no-sequences': 'error',
		'no-shadow': 'error',
		'no-shadow-restricted-names': 'error',
		'no-sparse-arrays': 'error',
		'no-sync': 'error',
		'no-tabs': 'off',
		'no-template-curly-in-string': 'error',
		'no-ternary': 'off',
		'no-this-before-super': 'error',
		'no-throw-literal': 'error',
		'no-trailing-spaces': 'error',
		'no-undef': 'error',
		'no-undef-init': 'error',
		'no-undefined': 'error',
		'no-underscore-dangle': 'error',
		'no-unexpected-multiline': 'error',
		'no-unmodified-loop-condition': 'error',
		'no-unneeded-ternary': 'error',
		'no-unreachable': 'error',
		'no-unsafe-finally': 'error',
		'no-unsafe-negation': 'error',
		'no-unused-expressions': 'error',
		'no-unused-labels': 'error',
		'no-unused-vars': 'error',
		'no-use-before-define': ['error', 'nofunc'],
		'no-useless-call': 'error',
		'no-useless-computed-key': 'error',
		'no-useless-concat': 'error',
		'no-useless-constructor': 'error',
		'no-useless-escape': 'error',
		'no-useless-rename': 'error',
		'no-useless-return': 'error',
		'no-var': 'error',
		'no-void': 'error',
		'no-warning-comments': 'error',
		'no-whitespace-before-property': 'error',
		'no-with': 'error',
		'nonblock-statement-body-position': 'off',
		'object-curly-newline': 'off',
		'object-curly-spacing': ['error', 'always'],
		'object-property-newline': ['error', {
			allowMultiplePropertiesPerLine: true,
		}],
		'object-shorthand': 'error',
		'one-var': ['error', 'never'],
		'one-var-declaration-per-line': ['error', 'always'],
		'operator-assignment': 'error',
		'operator-linebreak': ['error', 'after', {
			overrides: {
				':': 'before',
				'?': 'before',
			},
		}],
		'padded-blocks': ['error', 'never'],
		'padding-line-between-statements': [
			'error',
			{
				blankLine: 'always',
				prev: ['const', 'let', 'var'],
				// eslint-disable-next-line sort-keys
				next: '*',
			},
			{
				blankLine: 'any',
				prev: ['const', 'let', 'var'],
				// eslint-disable-next-line sort-keys
				next: ['const', 'let', 'var'],
			},
			{
				blankLine: 'always',
				prev: '*',
				// eslint-disable-next-line sort-keys
				next: 'return',
			},
		],
		'prefer-arrow-callback': ['error', { allowNamedFunctions: true }],
		'prefer-const': 'error',
		'prefer-destructuring': 'error',
		'prefer-numeric-literals': 'error',
		'prefer-promise-reject-errors': 'error',
		'prefer-rest-params': 'error',
		'prefer-spread': 'error',
		'prefer-template': 'error',
		'quote-props': ['error', 'as-needed'],
		quotes: ['error', 'single'],
		radix: 'error',
		'require-await': 'error',
		'require-jsdoc': 'off',
		'require-yield': 'error',
		'rest-spread-spacing': 'error',
		semi: ['error', 'always'],
		'semi-spacing': 'error',
		'semi-style': 'error',
		'sort-imports': 'error',
		'sort-keys': 'error',
		'sort-vars': 'error',
		'space-before-blocks': 'error',
		'space-before-function-paren': ['error', 'never'],
		'space-in-parens': ['error', 'never'],
		'space-infix-ops': 'error',
		'space-unary-ops': 'error',
		'spaced-comment': 'error',
		strict: ['error', 'never'],
		'switch-colon-spacing': 'error',
		'symbol-description': 'error',
		'template-curly-spacing': 'error',
		'template-tag-spacing': 'error',
		'unicode-bom': 'error',
		'use-isnan': 'error',
		'valid-jsdoc': 'error',
		'valid-typeof': ['error', { requireStringLiterals: true }],
		'vars-on-top': 'error',
		'wrap-iife': 'error',
		'wrap-regex': 'error',
		'yield-star-spacing': ['error', 'both'],
		yoda: 'error',
	},
};
